# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class UpdateTransactionRequest(BaseModel):
    """
    UpdateTransactionRequest
    """ # noqa: E501
    description: Optional[StrictStr] = None
    var_date: Optional[date] = Field(default=None, alias="date")
    paid: Optional[StrictBool] = None
    amount_cents: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=-2147483647)]] = None
    account_id: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = Field(default=None, description="ID of the Bank Account")
    category_id: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None
    notes: Optional[StrictStr] = None
    credit_card_id: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None
    tags: Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=100)]] = None
    update_future: Optional[StrictBool] = None
    update_all: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["description", "date", "paid", "amount_cents", "account_id", "category_id", "notes", "credit_card_id", "tags", "update_future", "update_all"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpdateTransactionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if notes (nullable) is None
        # and model_fields_set contains the field
        if self.notes is None and "notes" in self.model_fields_set:
            _dict['notes'] = None

        # set to None if credit_card_id (nullable) is None
        # and model_fields_set contains the field
        if self.credit_card_id is None and "credit_card_id" in self.model_fields_set:
            _dict['credit_card_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpdateTransactionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "date": obj.get("date"),
            "paid": obj.get("paid"),
            "amount_cents": obj.get("amount_cents"),
            "account_id": obj.get("account_id"),
            "category_id": obj.get("category_id"),
            "notes": obj.get("notes"),
            "credit_card_id": obj.get("credit_card_id"),
            "tags": obj.get("tags"),
            "update_future": obj.get("update_future"),
            "update_all": obj.get("update_all")
        })
        return _obj


