# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.bank_account import BankAccount

class TestBankAccount(unittest.TestCase):
    """BankAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BankAccount:
        """Test BankAccount
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BankAccount`
        """
        model = BankAccount()
        if include_optional:
            return BankAccount(
                id = 1,
                name = '',
                institution_id = '',
                institution_name = '',
                description = '',
                archived = True,
                created_at = '-8072i_0408 20012345678910111213141516171819',
                updated_at = '-8072i_0408 20012345678910111213141516171819',
                default = True,
                type = 'checking'
            )
        else:
            return BankAccount(
        )
        """

    def testBankAccount(self):
        """Test BankAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
