# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.budgets_api import BudgetsApi


class TestBudgetsApi(unittest.TestCase):
    """BudgetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BudgetsApi()

    def tearDown(self) -> None:
        pass

    def test_list_annual_budgets(self) -> None:
        """Test case for list_annual_budgets

        Get Annual Budgets
        """
        pass

    def test_list_current_month_budgets(self) -> None:
        """Test case for list_current_month_budgets

        Get Current Month Budgets
        """
        pass

    def test_list_monthly_budgets(self) -> None:
        """Test case for list_monthly_budgets

        Get Monthly Budgets
        """
        pass


if __name__ == '__main__':
    unittest.main()
